==> vtigercrm-5.0.3.tgz: vtigercrm/modules/System/includes/lang/pl.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: pl.php,v 1.12 2005/12/31 17:25:02 bigmichi1 Exp $

$charset                = 'iso-8859-2';

$text['title']          = 'Informacja o systemie';

$text['vitals']         = 'Stan systemu';
$text['hostname']       = 'Nazwa kanoniczna hosta';
$text['ip']             = 'IP nasuchujcy';
$text['kversion']       = 'Wersja jdra';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Obecnych uytkownkw';
$text['loadavg']        = 'Obcienia rednie';

$text['hardware']       = 'Informacja o sprzcie';
$text['numcpu']         = 'Procesory';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'Cz&#281;stotliwo&#347;&#263;';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cache Size';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = 'Urzdzenia PCI';
$text['ide']            = 'Urzdzenia IDE';
$text['scsi']           = 'Urzdzenia SCSI';
$text['usb']            = 'Urzdzenia USB';

$text['netusage']       = 'Sie';
$text['device']         = 'Urzdzenie';
$text['received']       = 'Odebrano';
$text['sent']           = 'Wysano';
$text['errors']         = 'Bdow/Porzuconych';

$text['memusage']       = 'Obcienie pamici';
$text['phymem']         = 'Pami fizyczna';
$text['swap']           = 'Pami Swap';

$text['fs']             = 'Zamontowane systemy plikw';
$text['mount']          = 'Punkt montowania';
$text['partition']      = 'Partycja';

$text['percent']        = 'Procentowo zajte';
$text['type']           = 'Typ';
$text['free']           = 'Wolne';
$text['used']           = 'Zajte';
$text['size']           = 'Rozmiar';
$text['totals']         = 'Cakowite';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'brak';

$text['capacity']       = 'Rozmiar';

$text['template']       = 'Szablon';
$text['language']       = 'Jzyk';
$text['submit']         = 'Wylij';
$text['created']        = 'Utworzone przez';
$text['locale']         = 'pl_PL'; 
$text['gen_time']       = " %e %b %Y o godzinie %T";

$text['days']           = 'dni';
$text['hours']          = 'godzin';
$text['minutes']        = 'minut';

$text['sensors']        = 'Czujniki (lm_sensors)';
$text['temperature']    = 'Temperatura';
$text['voltage']        = 'Napicia';
$text['fans']           = 'Wiatraczki';
$text['s_value']        = 'Warto';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hystereza';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Nazwa';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>

==> vtigercrm-5.2.1p2.tgz: vtigercrm/modules/System/includes/lang/pl.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: pl.php,v 1.12 2005/12/31 17:25:02 bigmichi1 Exp $

$charset                = 'UTF-8';

$text['title']          = 'Informacja o systemie';

$text['vitals']         = 'Stan systemu';
$text['hostname']       = 'Nazwa kanoniczna hosta';
$text['ip']             = 'IP nasuchujcy';
$text['kversion']       = 'Wersja jdra';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Obecnych uytkownkw';
$text['loadavg']        = 'Obcienia rednie';

$text['hardware']       = 'Informacja o sprzcie';
$text['numcpu']         = 'Procesory';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'Cz&#281;stotliwo&#347;&#263;';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cache Size';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = 'Urzdzenia PCI';
$text['ide']            = 'Urzdzenia IDE';
$text['scsi']           = 'Urzdzenia SCSI';
$text['usb']            = 'Urzdzenia USB';

$text['netusage']       = 'Sie';
$text['device']         = 'Urzdzenie';
$text['received']       = 'Odebrano';
$text['sent']           = 'Wysano';
$text['errors']         = 'Bdow/Porzuconych';

$text['memusage']       = 'Obcienie pamici';
$text['phymem']         = 'Pami fizyczna';
$text['swap']           = 'Pami Swap';

$text['fs']             = 'Zamontowane systemy plikw';
$text['mount']          = 'Punkt montowania';
$text['partition']      = 'Partycja';

$text['percent']        = 'Procentowo zajte';
$text['type']           = 'Typ';
$text['free']           = 'Wolne';
$text['used']           = 'Zajte';
$text['size']           = 'Rozmiar';
$text['totals']         = 'Cakowite';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'brak';

$text['capacity']       = 'Rozmiar';

$text['template']       = 'Szablon';
$text['language']       = 'Jzyk';
$text['submit']         = 'Wylij';
$text['created']        = 'Utworzone przez';
$text['locale']         = 'pl_PL'; 
$text['gen_time']       = " %e %b %Y o godzinie %T";

$text['days']           = 'dni';
$text['hours']          = 'godzin';
$text['minutes']        = 'minut';

$text['sensors']        = 'Czujniki (lm_sensors)';
$text['temperature']    = 'Temperatura';
$text['voltage']        = 'Napicia';
$text['fans']           = 'Wiatraczki';
$text['s_value']        = 'Warto';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hystereza';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Nazwa';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
